##  Overview
Collections allow users to organize dashboards, reports, and diagrams into custom groups. Both admins and users with the appropriate permissions can create and manage collections. Once collections are defined, users can add any number of dashboards, reports, and diagrams to them.
Non-empty collections appear on the left-side panel on the dashboards, reports, and diagrams pages. Collections that contain no items do not appear on the left-side panel. Once users add at least one item to a collection, it becomes visible on the left-side panel of the corresponding page. Subcollections, or collections within other collections, appear as folders.
![Collection Groups and Collections on the Reports Page](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2754c5c87a44101496af819f58df941f_LowRes.png)
Collection Groups and Collections on the Reports Page
